==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/vco21.cpp <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

#include "hco21.h"

const t_FuncBufDesc CO_FunctionDesc[] = 
{
  3, (char*)"COPY_AND_REG_DLL", 4, &co_IntrospectFunction1,
  4, (char*)"ACTIVATE_DLL", 1, &co_IntrospectFunction2,
  5, (char*)"REG_DLL", 1, &co_IntrospectFunction3,
  6, (char*)"SYSDDLTRIGGER", 0, &co_IntrospectFunction4,
  7, (char*)"FORCE_CHECKPOINT", 1, &co_IntrospectFunction5,
  8, (char*)"WAIT_FOR_CHECKPOINT", 1, &co_IntrospectFunction6,
  9, (char*)"FORCE_AND_WAIT_FOR_CHECKPOINT", 0, &co_IntrospectFunction7,
  10, (char*)"DROP_CURSOR", 0, &co_IntrospectFunction8};

extern "C" void __stdcall Co_IntrospectObject (  LPCLSID      *lpClsId,
                                       LPIID          *lpIId,
                                       unsigned short *lpNum,
                                       long           *lpVersion )
{
  *lpClsId        = (LPCLSID)&CLSID_Intro;
  *lpIId          = (LPIID)&IID_Intro;
  *lpNum          = PROCEDURE_NUM;
  *lpVersion      = VERSION_NUMBER;
};

  enum Co_AccessType
{
    get_by_name,
    get_by_index
};

extern "C" void __stdcall Co_IntrospectMethod ( Co_AccessType   accessType, 
                                      char            **lplpMethod, 
                                      unsigned short  Num,
                                      unsigned short  *lpIdx,
                                      unsigned short  *lpParamCount,
                                      CO_INTROSPECTFUNCTION *lplpIntrospecFunc )
{
  *lplpIntrospecFunc = NULL;
  if (accessType == get_by_name)
  {
	  if ( **lplpMethod == '\0' )
    {
        *lpIdx             = CO_FunctionDesc[0].FuncIdx;
        *lpParamCount      = CO_FunctionDesc[0].ParamCount;
        *lplpIntrospecFunc = CO_FunctionDesc[0].lpFunction;
        *lplpMethod        = CO_FunctionDesc[0].lpMethod;
    }
    else 
    for ( int i=0; i < PROCEDURE_NUM; i++ )
      if ( 0 == strcmp(*lplpMethod, CO_FunctionDesc[i].lpMethod ))
      {
        *lpIdx             = CO_FunctionDesc[i].FuncIdx;
        *lpParamCount      = CO_FunctionDesc[i].ParamCount;
        *lplpIntrospecFunc = CO_FunctionDesc[i].lpFunction;
      }
  }
  else
  {
    if ( Num <= PROCEDURE_NUM )
      {
        *lpIdx             = CO_FunctionDesc[Num].FuncIdx;
        *lpParamCount      = CO_FunctionDesc[Num].ParamCount;
        *lplpIntrospecFunc = CO_FunctionDesc[Num].lpFunction;
        *lplpMethod        = CO_FunctionDesc[Num].lpMethod;
      }
  }
};

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/vco21.cpp <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

#include "hco21.h"

const t_FuncBufDesc CO_FunctionDesc[] = 
{
  3, (char*)"COPY_AND_REG_DLL", 4, &co_IntrospectFunction1,
  4, (char*)"ACTIVATE_DLL", 1, &co_IntrospectFunction2,
  5, (char*)"REG_DLL", 1, &co_IntrospectFunction3,
  6, (char*)"SYSDDLTRIGGER", 0, &co_IntrospectFunction4,
  7, (char*)"FORCE_CHECKPOINT", 1, &co_IntrospectFunction5,
  8, (char*)"WAIT_FOR_CHECKPOINT", 1, &co_IntrospectFunction6,
  9, (char*)"FORCE_AND_WAIT_FOR_CHECKPOINT", 0, &co_IntrospectFunction7,
  10, (char*)"DROP_CURSOR", 0, &co_IntrospectFunction8,
  11, (char*)"DROP_SCHEMAS", 0, &co_IntrospectFunction9};

extern "C" void __stdcall Co_IntrospectObject (  LPCLSID      *lpClsId,
                                       LPIID          *lpIId,
                                       unsigned short *lpNum,
                                       long           *lpVersion )
{
  *lpClsId        = (LPCLSID)&CLSID_Intro;
  *lpIId          = (LPIID)&IID_Intro;
  *lpNum          = PROCEDURE_NUM;
  *lpVersion      = VERSION_NUMBER;
};

  enum Co_AccessType
{
    get_by_name,
    get_by_index
};

extern "C" void __stdcall Co_IntrospectMethod ( Co_AccessType   accessType, 
                                      char            **lplpMethod, 
                                      unsigned short  Num,
                                      unsigned short  *lpIdx,
                                      unsigned short  *lpParamCount,
                                      CO_INTROSPECTFUNCTION *lplpIntrospecFunc )
{
  *lplpIntrospecFunc = NULL;
  if (accessType == get_by_name)
  {
	  if ( **lplpMethod == '\0' )
    {
        *lpIdx             = CO_FunctionDesc[0].FuncIdx;
        *lpParamCount      = CO_FunctionDesc[0].ParamCount;
        *lplpIntrospecFunc = CO_FunctionDesc[0].lpFunction;
        *lplpMethod        = CO_FunctionDesc[0].lpMethod;
    }
    else 
    for ( int i=0; i < PROCEDURE_NUM; i++ )
      if ( 0 == strcmp(*lplpMethod, CO_FunctionDesc[i].lpMethod ))
      {
        *lpIdx             = CO_FunctionDesc[i].FuncIdx;
        *lpParamCount      = CO_FunctionDesc[i].ParamCount;
        *lplpIntrospecFunc = CO_FunctionDesc[i].lpFunction;
      }
  }
  else
  {
    if ( Num <= PROCEDURE_NUM ) 
      {
        *lpIdx             = CO_FunctionDesc[Num].FuncIdx;
        *lpParamCount      = CO_FunctionDesc[Num].ParamCount;
        *lplpIntrospecFunc = CO_FunctionDesc[Num].lpFunction;
        *lplpMethod        = CO_FunctionDesc[Num].lpMethod;
      }
  }
};
